AssetConfig class

Asset analysis configuration

Annotations
  • @JsonSerializable.new()

Constructors

AssetConfig({required int maxAssetSize, required List<String> excludeExtensions, required List<String> excludePaths, required bool optimizeImages, required int optimizeQuality, required List<String> imageFormats})
const
AssetConfig.defaults()
factory
AssetConfig.fromJson(Map<String, dynamic> json)
factory

Properties

excludeExtensions List<String>
File extensions to exclude from analysis
final
excludePaths List<String>
Paths to exclude from analysis
final
hashCode int
The hash code for this object.
no setterinherited
imageFormats List<String>
Image formats to analyze
final
maxAssetSize int
Maximum size for assets in bytes (default: 1MB)
final
optimizeImages bool
Whether to optimize images
final
optimizeQuality int
Quality for image optimization (0-100)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited