DependencyAnalysisResult class

Result of dependency analysis

Constructors

DependencyAnalysisResult({required int totalDependencies, required int totalDevDependencies, required List<String> unusedDependencies, required List<String> unusedDevDependencies, required Map<String, PackageInfo> packageInfo})

Properties

hashCode int
The hash code for this object.
no setterinherited
hasUnused bool
no setter
packageInfo Map<String, PackageInfo>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalDependencies int
final
totalDevDependencies int
final
totalUnused int
no setter
unusedDependencies List<String>
final
unusedDevDependencies List<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited